// Code generated by modernc.org/undup from the per-target sqlite_*.go files; DO NOT EDIT.

//go:build (freebsd && 386) || (freebsd && amd64) || (linux && 386) || (linux && amd64) || (linux && ppc64le) || (netbsd && amd64) || (openbsd && amd64) || (windows && (amd64 || arm64)) || (windows && 386)

package sqlite3

const __SIZEOF_FLOAT128__ = 16
