// Code generated by modernc.org/undup from the per-target sqlite_*.go files; DO NOT EDIT.

//go:build (darwin && amd64) || (darwin && arm64) || (linux && 386) || (linux && amd64) || (linux && arm) || (linux && arm64) || (linux && loong64) || (linux && ppc64le) || (linux && riscv64) || (linux && s390x) || (windows && (amd64 || arm64)) || (windows && 386)

package sqlite3

const HUGE = 0

const INT_FAST8_MAX = 127

const INT_FAST8_MIN = -128

type Tint_fast8_t = int8

type Tuint_fast8_t = uint8

const UINT_FAST8_MAX = 255
