// Code generated by modernc.org/undup from the per-target sqlite_*.go files; DO NOT EDIT.

//go:build (linux && amd64) || (linux && arm) || (linux && arm64) || (linux && loong64) || (linux && ppc64le) || (linux && riscv64) || (linux && s390x) || (netbsd && amd64)

package sqlite3

const __FLT_EVAL_METHOD_TS_18661_3__ = 0

const __FLT_EVAL_METHOD__ = 0
